@@ -2,6 +2,7 @@
 # SPDX-License-Identifier: GPL-2.0-or-later
 
 import logging
+import os
 import os.path
 import typing
 
@@ -11,7 +12,10 @@ from ecleankernel.bootloader.lilo import LILO
 class GRUB(LILO):
     name = 'grub'
     kernel_re = r'^\s*(kernel|module)\s*(\([^)]+\))?(?P<path>\S+)'
-    def_path = ('/boot/grub/menu.lst', '/boot/grub/grub.conf')
+    def_path = (os.environ.get("GRUB_CFG"),
+                '/boot/grub/menu.lst',
+                '/boot/grub/grub.conf',
+                )
 
     def _get_kernels(self,
                      content: str
